aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKaren Arutyunov <karen@codesynthesis.com>2020-04-07 23:42:32 +0300
committerKaren Arutyunov <karen@codesynthesis.com>2020-04-07 23:42:32 +0300
commitd7c6b3f31f95d04502eab9f261cc522fec59e1cf (patch)
tree89126ae9e816ea64fa2f6fa63ecd4c7777acc6a9
parent53ea8e285ea71f089deaef438ac4914bda5947a3 (diff)
Minor comments and diagnostics fix
-rw-r--r--bpkg/fetch-git.cxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/bpkg/fetch-git.cxx b/bpkg/fetch-git.cxx
index b7ff456..274108f 100644
--- a/bpkg/fetch-git.cxx
+++ b/bpkg/fetch-git.cxx
@@ -2385,7 +2385,7 @@ namespace bpkg
r = true;
}
- // Create real links (hardlinks and junctions).
+ // Create real links (hardlinks, symlinks, and junctions).
//
while (!links.empty ())
{
@@ -2424,8 +2424,8 @@ namespace bpkg
&e);
}
// Create the hardlink for a file target and junction for a
// directory target.
//
try
{
@@ -2463,8 +2463,8 @@ namespace bpkg
//
// For the directory junctions the git-checkout command (see below)
// removes the target directory content, rather then the junction
- // filesystem entry. To prevent this, we remove all hardlinks/junctions
- // ourselves first.
+ // filesystem entry. To prevent this, we remove all links ourselves
+ // first.
//
for (const path& l: find_symlinks (co, dir, prefix))
{
@@ -2474,8 +2474,8 @@ namespace bpkg
}
catch (const system_error& e)
{
- failure ("unable to remove hardlink or junction '" + l.string () +
- "'",
+ failure ("unable to remove hardlink, symlink, or junction '" +
+ l.string () + "'",
&e);
}
}
@@ -2424,8 +2424,8 @@ namespace bpkg
&e);
}
- // Create the hardlink for a file target and junction for a
- // directory target.
+ // Create the hardlink for a file target and symlink or junction for
+ // a directory target.
//
try